@@ -147,9 +147,7 @@ gsm_shell_class_init (GsmShellClass *shell_class)
                               G_OBJECT_CLASS_TYPE (object_class),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (GsmShellClass, end_session_dialog_opened),
-                              NULL,
-                              NULL,
-                              g_cclosure_marshal_VOID__VOID,
+                              NULL, NULL, NULL,
                               G_TYPE_NONE, 0);
 
         signals [END_SESSION_DIALOG_OPEN_FAILED] =
@@ -157,9 +155,7 @@ gsm_shell_class_init (GsmShellClass *shell_class)
                               G_OBJECT_CLASS_TYPE (object_class),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (GsmShellClass, end_session_dialog_open_failed),
-                              NULL,
-                              NULL,
-                              g_cclosure_marshal_VOID__VOID,
+                              NULL, NULL, NULL,
                               G_TYPE_NONE, 0);
 
         signals [END_SESSION_DIALOG_CLOSED] =
@@ -167,9 +163,7 @@ gsm_shell_class_init (GsmShellClass *shell_class)
                               G_OBJECT_CLASS_TYPE (object_class),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (GsmShellClass, end_session_dialog_closed),
-                              NULL,
-                              NULL,
-                              g_cclosure_marshal_VOID__VOID,
+                              NULL, NULL, NULL,
                               G_TYPE_NONE, 0);
 
         signals [END_SESSION_DIALOG_CANCELED] =
@@ -177,9 +171,7 @@ gsm_shell_class_init (GsmShellClass *shell_class)
                               G_OBJECT_CLASS_TYPE (object_class),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (GsmShellClass, end_session_dialog_canceled),
-                              NULL,
-                              NULL,
-                              g_cclosure_marshal_VOID__VOID,
+                              NULL, NULL, NULL,
                               G_TYPE_NONE, 0);
 
         signals [END_SESSION_DIALOG_CONFIRMED_LOGOUT] =
@@ -187,9 +179,7 @@ gsm_shell_class_init (GsmShellClass *shell_class)
                               G_OBJECT_CLASS_TYPE (object_class),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (GsmShellClass, end_session_dialog_confirmed_logout),
-                              NULL,
-                              NULL,
-                              g_cclosure_marshal_VOID__VOID,
+                              NULL, NULL, NULL,
                               G_TYPE_NONE, 0);
 
         signals [END_SESSION_DIALOG_CONFIRMED_SHUTDOWN] =
@@ -197,9 +187,7 @@ gsm_shell_class_init (GsmShellClass *shell_class)
                               G_OBJECT_CLASS_TYPE (object_class),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (GsmShellClass, end_session_dialog_confirmed_shutdown),
-                              NULL,
-                              NULL,
-                              g_cclosure_marshal_VOID__VOID,
+                              NULL, NULL, NULL,
                               G_TYPE_NONE, 0);
 
         signals [END_SESSION_DIALOG_CONFIRMED_REBOOT] =
@@ -207,9 +195,7 @@ gsm_shell_class_init (GsmShellClass *shell_class)
                               G_OBJECT_CLASS_TYPE (object_class),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (GsmShellClass, end_session_dialog_confirmed_reboot),
-                              NULL,
-                              NULL,
-                              g_cclosure_marshal_VOID__VOID,
+                              NULL, NULL, NULL,
                               G_TYPE_NONE, 0);
 
         g_type_class_add_private (shell_class, sizeof (GsmShellPrivate));
@@ -319,20 +305,10 @@ gsm_shell_ensure_connection (GsmShell  *shell,
                 g_debug ("GsmShell: Not connected to the shell");
 
                 if (shell->priv->bus_connection == NULL) {
-                        if (shell->priv->bus_proxy != NULL) {
-                                g_object_unref (shell->priv->bus_proxy);
-                                shell->priv->bus_proxy = NULL;
-                        }
-
-                        if (shell->priv->proxy != NULL) {
-                                g_object_unref (shell->priv->proxy);
-                                shell->priv->proxy = NULL;
-                        }
+                        g_clear_object (&shell->priv->bus_proxy);
+                        g_clear_object (&shell->priv->proxy);
                 } else if (shell->priv->bus_proxy == NULL) {
-                        if (shell->priv->proxy != NULL) {
-                                g_object_unref (shell->priv->proxy);
-                                shell->priv->proxy = NULL;
-                        }
+                        g_clear_object (&shell->priv->proxy);
                 }
         }
 
@@ -350,10 +326,7 @@ gsm_shell_on_name_owner_changed (DBusGProxy    *bus_proxy,
                 return;
         }
 
-        if (shell->priv->proxy != NULL) {
-                g_object_unref (shell->priv->proxy);
-                shell->priv->proxy = NULL;
-        }
+        g_clear_object (&shell->priv->proxy);
 
         gsm_shell_ensure_connection (shell, NULL);
 }
@@ -369,15 +342,8 @@ gsm_shell_init (GsmShell *shell)
 static void
 gsm_shell_disconnect_from_bus (GsmShell *shell)
 {
-        if (shell->priv->bus_proxy != NULL) {
-                g_object_unref (shell->priv->bus_proxy);
-                shell->priv->bus_proxy = NULL;
-        }
-
-        if (shell->priv->proxy != NULL) {
-                g_object_unref (shell->priv->proxy);
-                shell->priv->proxy = NULL;
-        }
+        g_clear_object (&shell->priv->bus_proxy);
+        g_clear_object (&shell->priv->proxy);
 
         if (shell->priv->bus_connection != NULL) {
                 DBusConnection *connection;
@@ -568,6 +534,7 @@ static void
 on_end_session_dialog_proxy_destroyed (DBusGProxy *proxy,
                                        GsmShell   *shell)
 {
+        /* FIXME - is this right? */
         if (shell->priv->end_session_dialog_proxy != NULL) {
                 g_object_unref (shell->priv->proxy);
                 shell->priv->end_session_dialog_proxy = NULL;
