@@ -191,7 +191,7 @@ gsm_util_set_autostart_dirs (char ** dirs)
 }
 
 static char **
-gsm_util_get_standard_autostart_dirs ()
+gsm_util_get_standard_autostart_dirs (void)
 {
         GPtrArray          *dirs;
         const char * const *system_config_dirs;
@@ -544,9 +544,7 @@ gsm_util_update_activation_environment (const char  *variable,
 
  out:
 
-        if (bus_proxy != NULL) {
-                g_object_unref (bus_proxy);
-        }
+        g_clear_object (&bus_proxy);
 
         if (environment != NULL) {
                 g_hash_table_destroy (environment);
