@@ -32,12 +32,13 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
+#include <glib-unix.h>
+
 #include <dbus/dbus.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-bindings.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
-#include "gdm-signal-handler.h"
 #include "gdm-log.h"
 
 #include "gsm-util.h"
@@ -45,7 +46,6 @@
 #include "gsm-session-fill.h"
 #include "gsm-store.h"
 #include "gsm-system.h"
-#include "gsm-xsmp-server.h"
 #include "gsm-fail-whale-dialog.h"
 
 #define GSM_DBUS_NAME "org.gnome.SessionManager"
@@ -173,49 +173,23 @@ acquire_name (void)
 }
 
 static gboolean
-signal_cb (int      signo,
-           gpointer data)
+term_or_int_signal_cb (gpointer data)
 {
-        int ret;
-        GsmManager *manager;
+        GsmManager *manager = (GsmManager *)data;
 
-        g_debug ("Got callback for signal %d", signo);
+        /* let the fatal signals interrupt us */
+        g_debug ("Caught SIGINT/SIGTERM, shutting down normally.");
 
-        ret = TRUE;
+        gsm_manager_logout (manager, GSM_MANAGER_LOGOUT_MODE_FORCE, NULL);
 
-        switch (signo) {
-        case SIGFPE:
-        case SIGPIPE:
-                /* let the fatal signals interrupt us */
-                g_debug ("Caught signal %d, shutting down abnormally.", signo);
-                ret = FALSE;
-                break;
-        case SIGINT:
-        case SIGTERM:
-                manager = (GsmManager *)data;
-                gsm_manager_logout (manager, GSM_MANAGER_LOGOUT_MODE_FORCE, NULL);
+        return FALSE;
+}
 
-                /* let the fatal signals interrupt us */
-                g_debug ("Caught signal %d, shutting down normally.", signo);
-                ret = TRUE;
-                break;
-        case SIGHUP:
-                g_debug ("Got HUP signal");
-                ret = TRUE;
-                break;
-        case SIGUSR1:
-                g_debug ("Got USR1 signal");
-                ret = TRUE;
-                gdm_log_toggle_debug ();
-                break;
-        default:
-                g_debug ("Caught unhandled signal %d", signo);
-                ret = TRUE;
-
-                break;
-        }
-
-        return ret;
+static gboolean
+sigusr1_cb (gpointer data)
+{
+        gdm_log_toggle_debug ();
+        return TRUE;
 }
 
 static void
@@ -278,18 +252,16 @@ require_dbus_session (int      argc,
 int
 main (int argc, char **argv)
 {
-        struct sigaction  sa;
         GError           *error;
         char             *display_str;
         GsmManager       *manager;
         GsmStore         *client_store;
-        GsmXsmpServer    *xsmp_server;
-        GdmSignalHandler *signal_handler;
         static char     **override_autostart_dirs = NULL;
-        static char      *session_name = NULL;
+        static char      *opt_session_name = NULL;
+        const char       *session_name;
         static GOptionEntry entries[] = {
                 { "autostart", 'a', 0, G_OPTION_ARG_STRING_ARRAY, &override_autostart_dirs, N_("Override standard autostart directories"), N_("AUTOSTART_DIR") },
-                { "session", 0, 0, G_OPTION_ARG_STRING, &session_name, N_("Session to use"), N_("SESSION_NAME") },
+                { "session", 0, 0, G_OPTION_ARG_STRING, &opt_session_name, N_("Session to use"), N_("SESSION_NAME") },
                 { "debug", 0, 0, G_OPTION_ARG_NONE, &debug, N_("Enable debugging code"), NULL },
                 { "failsafe", 'f', 0, G_OPTION_ARG_NONE, &failsafe, N_("Do not load user-specified applications"), NULL },
                 { "version", 0, 0, G_OPTION_ARG_NONE, &show_version, N_("Version of this application"), NULL },
@@ -307,11 +279,6 @@ main (int argc, char **argv)
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
         textdomain (GETTEXT_PACKAGE);
 
-        sa.sa_handler = SIG_IGN;
-        sa.sa_flags = 0;
-        sigemptyset (&sa.sa_mask);
-        sigaction (SIGPIPE, &sa, 0);
-
         error = NULL;
         gtk_init_with_args (&argc, &argv,
                             (char *) _(" - the GNOME session manager"),
@@ -357,8 +324,6 @@ main (int argc, char **argv)
          */
         g_object_unref (gsm_get_system ());
 
-        xsmp_server = gsm_xsmp_server_new (client_store);
-
         if (!acquire_name ()) {
                 gsm_fail_whale_dialog_we_failed (TRUE, TRUE, NULL);
                 gtk_main ();
@@ -367,17 +332,14 @@ main (int argc, char **argv)
 
         manager = gsm_manager_new (client_store, failsafe);
 
-        signal_handler = gdm_signal_handler_new ();
-        gdm_signal_handler_add_fatal (signal_handler);
-        gdm_signal_handler_add (signal_handler, SIGFPE, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGHUP, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGUSR1, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGTERM, signal_cb, manager);
-        gdm_signal_handler_add (signal_handler, SIGINT, signal_cb, manager);
-        gdm_signal_handler_set_fatal_func (signal_handler, shutdown_cb, manager);
+        g_unix_signal_add (SIGTERM, term_or_int_signal_cb, manager);
+        g_unix_signal_add (SIGINT, term_or_int_signal_cb, manager);
+        g_unix_signal_add (SIGUSR1, sigusr1_cb, manager);
 
-        if (IS_STRING_EMPTY (session_name))
+        if (IS_STRING_EMPTY (opt_session_name))
                 session_name = _gsm_manager_get_default_session (manager);
+        else
+                session_name = opt_session_name;
 
         gsm_util_set_autostart_dirs (override_autostart_dirs);
 
@@ -385,27 +347,13 @@ main (int argc, char **argv)
                 gsm_util_init_error (TRUE, "Failed to load session \"%s\"", session_name ? session_name : "(null)");
         }
 
-        gsm_xsmp_server_start (xsmp_server);
         gsm_manager_start (manager);
 
         gtk_main ();
 
-        if (xsmp_server != NULL) {
-                g_object_unref (xsmp_server);
-        }
-
-        if (manager != NULL) {
-                g_debug ("Unreffing manager");
-                g_object_unref (manager);
-        }
-
-        if (client_store != NULL) {
-                g_object_unref (client_store);
-        }
-
-        if (bus_proxy != NULL) {
-                g_object_unref (bus_proxy);
-        }
+        g_clear_object (&manager);
+        g_clear_object (&client_store);
+        g_clear_object (&bus_proxy);
 
         gdm_log_shutdown ();
 
